@@ -1,4 +1,5 @@
-package SetterErrorModule;
+package
+SetterErrorModule;
 our $VERSION = '0.000001';
 
 use 5.014;
